package com.younike.system.service;

import java.util.List;
import com.younike.system.domain.OrderAddress;

/**
 * 订单服务地址Service接口
 * 
 * @author elev
 * @date 2022-01-07
 */
public interface IOrderAddressService {
    /**
     * 查询订单服务地址
     * 
     * @param orderId 订单服务地址主键
     * @return 订单服务地址
     */
    OrderAddress selectOrderAddressByOrderId(Long orderId);

    /**
     * 查询订单服务地址列表
     * 
     * @param orderAddress 订单服务地址
     * @return 订单服务地址集合
     */
    List<OrderAddress> selectOrderAddressList(OrderAddress orderAddress);

    /**
     * 新增订单服务地址
     * 
     * @param orderAddress 订单服务地址
     * @return 结果
     */
    int insertOrderAddress(OrderAddress orderAddress);

    /**
     * 修改订单服务地址
     * 
     * @param orderAddress 订单服务地址
     * @return 结果
     */
    int updateOrderAddress(OrderAddress orderAddress);

    /**
     * 批量删除订单服务地址
     * 
     * @param orderIds 需要删除的订单服务地址主键集合
     * @return 结果
     */
    int deleteOrderAddressByOrderIds(Long[] orderIds);

    /**
     * 删除订单服务地址信息
     * 
     * @param orderId 订单服务地址主键
     * @return 结果
     */
    int deleteOrderAddressByOrderId(Long orderId);
}
